@@ -10,6 +10,6 @@ from .annotation import Annotation, PolygonSegmentation, RLESegmentation, Segmen
 # flake8: noqa
 from .base import BandMeta, Image, ImageMeta, ImageSet, ImageSetSpatial
 from .kwcoco import KWCOCOArchive
-from .processed import ConvertedImage, RegionImage
+from .processed import ProcessedImage, ProcessedImageGroup
 from .raster import Raster, RasterMeta
 from .utility import *  # noqa
