@@ -34,6 +34,11 @@ urlpatterns = [
     path('api/rgd_imagery/raster/search', rest.search.SearchRasterMetaSTACView.as_view()),
     #############
     # Other
+    path(
+        'api/rgd_imagery',
+        rest.post.CreateImage.as_view(),
+        name='image-create',
+    ),
     path(
         'api/rgd_imagery/<int:pk>',
         rest.get.GetImageMeta.as_view(),
@@ -44,11 +49,31 @@ urlpatterns = [
         rest.download.download_image_file,
         name='image-entry-data',
     ),
+    path(
+        'api/rgd_imagery/image_set',
+        rest.post.CreateImageSet.as_view(),
+        name='image-set-create',
+    ),
     path(
         'api/rgd_imagery/image_set/<int:pk>',
         rest.get.GetImageSet.as_view(),
         name='image-set',
     ),
+    path(
+        'api/rgd_imagery/image_set_spatial',
+        rest.post.CreateImageSetSpatial.as_view(),
+        name='image-set-spatial-create',
+    ),
+    path(
+        'api/rgd_imagery/image_set_spatial/<int:pk>',
+        rest.get.GetImageSetSpatial.as_view(),
+        name='image-set-spatial',
+    ),
+    path(
+        'api/rgd_imagery/raster',
+        rest.post.CreateRaster.as_view(),
+        name='raster-create',
+    ),
     path(
         'api/rgd_imagery/raster/<int:pk>',
         rest.get.GetRasterMeta.as_view(),
@@ -111,29 +136,20 @@ urlpatterns = [
         rest.tiles.TileSingleBandInfoView.as_view(),
         name='image-bands-single',
     ),
-    path('api/image_process/imagery/cog', rest.post.CreateConvertedImage.as_view()),
+    path('api/image_process', rest.post.CreateProcessedImage.as_view(), name='processed-image'),
     path(
-        'api/image_process/imagery/cog/<int:pk>',
-        rest.get.GetConvertedImageStatus.as_view(),
-        name='cog',
+        'api/image_process/group',
+        rest.post.CreateProcessedImageGroup.as_view(),
+        name='processed-image-group',
     ),
     path(
-        'api/image_process/imagery/cog/<int:pk>/data',
-        rest.download.download_cog_file,
-        name='cog-data',
+        'api/image_process/<int:pk>',
+        rest.get.GetProcessedImage.as_view(),
+        name='get-processed-image',
     ),
     path(
-        'api/image_process/imagery/subsample',
-        rest.post.CreateRegionImage.as_view(),
-    ),
-    path(
-        'api/image_process/imagery/subsample/<int:pk>',
-        rest.get.GetRegionImage.as_view(),
-        name='subsampled',
-    ),
-    path(
-        'api/image_process/imagery/subsample/<int:pk>/status',
-        rest.download.get_status_subsampled_image,
-        name='subsampled-status',
+        'api/image_process/group/<int:pk>/status',
+        rest.get.get_processed_image_group_status,
+        name='processed-image-group-status',
     ),
 ]
